@@ -35,15 +35,17 @@ Functions
 * dumps
 * load
 * loads
-
+* readinto
 """
 
 from pyben import api, bencode, classes
-from pyben.api import dump, dumps, load, loads
+from pyben.api import dump, dumps, load, loadinto, loads, show
 from pyben.bencode import bendecode, benencode
 from pyben.classes import Bendecoder, Benencoder
+from pyben.exceptions import DecodeError, EncodeError, FilePathError
+from pyben.version import version
 
-__version__ = "0.2.6"
+__version__ = version
 __author__ = "alexpdev"
 
 __all__ = [
@@ -58,4 +60,9 @@ __all__ = [
     "dumps",
     "load",
     "loads",
+    "show",
+    "loadinto",
+    "DecodeError",
+    "FilePathError",
+    "EncodeError",
 ]
