@@ -36,8 +36,8 @@ class Bendecoder:
         """
         Initialize instance with optional pre compiled data.
 
-        Args:
-        ----
+        Parameters
+        ----------
         data : `bytes` or `bytearray`
             (Optional) (default=None) Target data for decoding.
 
@@ -50,9 +50,9 @@ class Bendecoder:
         """
         Extract contents from path/path-like and return Decoded data.
 
-        Args
-        ----
-        path : `str` or `path-like`
+        Parameters
+        ----------
+        item : `str` or `path-like`
             Path containing bencoded data.
 
         Raises
@@ -80,8 +80,8 @@ class Bendecoder:
         """
         Shortcut to Decode raw bencoded data.
 
-        Args
-        ----
+        Parameters
+        ----------
         data : ``bytes`` or `bytearray`
             Bendencoded `bytes`.
 
@@ -98,9 +98,9 @@ class Bendecoder:
         """
         Decode bencoded data.
 
-        Args
-        ----
-        bits : ``bytes``
+        Parameters
+        ----------
+        data : ``bytes``
             bencoded data for decoding.
 
         Returns
@@ -117,8 +117,8 @@ class Bendecoder:
         """
         Decode bencoded data.
 
-        Args
-        ----
+        Parameters
+        ----------
         bits : ``bytes``
             Bencoded data for decoding.
 
@@ -153,8 +153,8 @@ class Bendecoder:
         """
         Decode keys and values in dictionary.
 
-        Args
-        ----
+        Parameters
+        ----------
         bits : ``bytes`` or `bytearray`
             `Bytes` of data for decoding.
 
@@ -178,9 +178,9 @@ class Bendecoder:
         """
         Decode list and its contents.
 
-        Args
-        ----
-        bits : `bytearray`
+        Parameters
+        ----------
+        data : `bytearray`
             Bencoded data.
 
         Returns
@@ -202,8 +202,8 @@ class Bendecoder:
         """
         Decode string.
 
-        Args
-        ----
+        Parameters
+        ----------
         bits : ``bytes`` or `bytearray`
             Bencoded string.
 
@@ -213,7 +213,7 @@ class Bendecoder:
             Decoded string.
 
         """
-        match = re.match(br"(\d+):", bits)
+        match = re.match(rb"(\d+):", bits)
         word_size, start = int(match.groups()[0]), match.span()[1]
         finish = start + word_size
         word = bits[start:finish]
@@ -231,8 +231,8 @@ class Bendecoder:
         """
         Decode integer type.
 
-        Args
-        ----
+        Parameters
+        ----------
         bits : ``bytes`` or `bytearray`
             Bencoded intiger.
 
@@ -242,7 +242,7 @@ class Bendecoder:
             Decoded intiger.
 
         """
-        obj = re.match(br"i(-?\d+)e", bits)
+        obj = re.match(rb"i(-?\d+)e", bits)
         return int(obj.group(1)), obj.end()
 
 
@@ -253,9 +253,9 @@ class Benencoder:
         """
         Initialize Benencoder insance with optional pre compiled data.
 
-        Args:
-        ----
-        data : `any`
+        Parameters
+        ----------
+        data : any
             (Optional) Target data for encoding. Defaults to None.
 
         """
@@ -265,18 +265,19 @@ class Benencoder:
     @classmethod
     def dump(cls, data, path):
         """
-        Shortcut Classmethod for encoding data and writing to file.
+        Shortcut class method for encoding data and writing to file.
 
-        Args
-        ----
-        data : `any`
+        Parameters
+        ----------
+        data : any
             Raw data to be encoded, usually dict.txt
-        path : path-like or `BytesIO`
+        path : `str` or `os.PathLike` or `BytesIO`
             Where encoded data should be written to.py
 
         Returns
         -------
-        `bool` : Return True if success.txt
+        `bool` :
+            Return True if success.txt
 
         """
         encoded = cls(data).encode()
@@ -292,15 +293,15 @@ class Benencoder:
         """
         Shortcut method for encoding data and immediately returning it.
 
-        Args
-        ----
-        data : `any`
+        Parameters
+        ----------
+        data : any
             Raw data to be encoded usually a dictionary.
 
         Returns
         -------
-        `bytes`: Encoded data.
-
+        bytes:
+            Encoded data.
         """
         return cls(data).encode()
 
@@ -308,15 +309,15 @@ class Benencoder:
         """
         Encode data provided as an arguement or provided at initialization.
 
-        Args
-        ----
+        Parameters
+        ----------
         val : any, optional
             Data for encoding. Defaults to None.
 
         Returns
         -------
-        `bytes` : encoded data
-
+        `bytes` :
+            encoded data
         """
         if val is None:
             val = self.data
@@ -327,15 +328,15 @@ class Benencoder:
         """
         Encode data with bencode protocol.
 
-        Args
-        ----
-        bits : `bytes`
+        Parameters
+        ----------
+        val : `bytes`
             Bencoded data for decoding.
 
         Returns
         -------
-        any : the decoded data.
-
+        any :
+            the decoded data.
         """
         if isinstance(val, str):
             return self._encode_str(val)
@@ -368,15 +369,15 @@ class Benencoder:
         """
         Decode string.
 
-        Args
-        ----
+        Parameters
+        ----------
         txt : `str`
             Any string literal.
 
         Returns
         -------
-        `bytes` : Bencoded string.
-
+        `bytes` :
+            Bencoded string.
         """
         size = str(len(txt)).encode("utf-8")
         return size + b":" + txt.encode("utf-8")
@@ -386,15 +387,15 @@ class Benencoder:
         """
         Encode intiger.
 
-        Args
-        ----
+        Parameters
+        ----------
         num : `int`
             Integer for encoding.
 
         Returns
         -------
-        `bytes` : Bencoded intiger.
-
+        `bytes` :
+            Bencoded intiger.
         """
         return b"i" + str(num).encode("utf-8") + b"e"
 
@@ -402,15 +403,15 @@ class Benencoder:
         """
         Encode list and its contents.
 
-        Args
-        ----
+        Parameters
+        ----------
         elems : `list`
             List of content to be encoded.
 
         Returns
         -------
-        `bytes` : Bencoded data
-
+        `bytes` :
+            Bencoded data
         """
         lst = [b"l"]
         for elem in elems:
@@ -424,15 +425,15 @@ class Benencoder:
         """
         Encode keys and values in dictionary.
 
-        Args
-        ----
+        Parameters
+        ----------
         dic : `dict`
             Dictionary of data for encoding.
 
         Returns
         -------
-        `bytes` : Bencoded data.
-
+        `bytes` :
+            Bencoded data.
         """
         result = b"d"
         for key, val in dic.items():
