@@ -22,11 +22,10 @@ class DecodeError(Exception):
     Mostly it indicates the object is a hash digest and should remian
     as a bytes object.
 
-    Args:
-    ----
-    val : any
+    Parameters
+    ----------
+    val : None
         Value that cause the exception
-
     """
 
     def __init__(self, val=None):
@@ -43,11 +42,10 @@ class EncodeError(Exception):
     data type into bencode format. Bencode accepts lists, dicts,
     strings, integers, and bytes.
 
-    Args:
-    ----
-    val : any
+    Parameters
+    ----------
+    val : None
         Value that cause the exception
-
     """
 
     def __init__(self, val=None):
@@ -62,11 +60,10 @@ class FilePathError(Exception):
     Generally raised when the file at the path specified
     does not exist.
 
-    Args:
-    ----
-    val : any
+    Parameters
+    ----------
+    obj : None
         Value that cause the exception
-
     """
 
     def __init__(self, obj=None):
